package com.myfood.mvp.addshopproduct

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.fragment.app.Fragment
import com.myfood.R
import com.myfood.constants.Constant
import com.myfood.constants.Constant.Companion.MODE_ADD
import com.myfood.databases.databasemysql.entity.ShopProductEntity
import com.myfood.databinding.AddShopFragmentBinding
import com.myfood.mvp.shoplist.ShopListFragment
import com.myfood.popup.Popup


class AddShopFragment(private val mode: Int, private var idShop: String = "") : Fragment(),
    AddShopContract.View {

    //Declaración de variables globales
    private var _binding: AddShopFragmentBinding? = null
    private val binding get() = _binding!!
    private lateinit var addShopPresenter: AddShopPresenter
    private var mutableTranslations: MutableMap<String, String> = mutableMapOf()

    //Método onCreateView
    //Mientras se está creando la vista
    override fun onCreateView(
        inflater: LayoutInflater, container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        //Usamos un binding para utilizar en la clase los elementos de la pantalla
        //Añadir Producto Compra
        _binding = AddShopFragmentBinding.inflate(inflater, container, false)
        return binding.root
    }

    //Método onViewCreated
    //Cuando la vista está creada
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        //Hacemos que el layout principal sea invisible hasta que no se carguen los datos
        binding.layoutAddShop.visibility = View.INVISIBLE

        //Creamos el presentador
        addShopPresenter = AddShopPresenter(this, requireContext())

        //Obtenemos las unidades de cantidad de la App y las asignamos al combo
        setQuantities()

        //Obtenemos las traducciones de pantalla
        this.mutableTranslations = addShopPresenter.getTranslationsScreen()
        setTranslations()

        //Si venimos del modo modidicar cargamos los datos
        if (mode == Constant.MODE_UPDATE) {
            addShopPresenter.getShopProduct(idShop)
        }

        //Inicializamos el click del boton añadir
        binding.btnASProduct.setOnClickListener { addUpdateShopToDB() }
    }

    //Se ejecuta cada vez que se viene del modo modificar el producto de compra
    override fun onLoadShopToUpdate(shopProductEntity: ShopProductEntity) {

        //Verificamos que la respuesta es correcta
        if (shopProductEntity.status == Constant.OK) {

            //Cargamos los campos de texto y combo
            binding.etASName.setText(shopProductEntity.name)
            binding.etASQuantity.setText(shopProductEntity.quantity)
            binding.sASQuantityUnit.setSelection(
                addShopPresenter.getPositionQuantitiesUnit(shopProductEntity.quantityUnit)
            )
        }
    }

    //Se ejecuta una vez se recuperan todas las unidades de cantidad de la App
    private fun setQuantities() {
        binding.sASQuantityUnit.adapter = addShopPresenter.createAdapterQuantitiesUnit()
    }

    //Método que añade un producto de compra a la basde de datos
    private fun addUpdateShopToDB() {

        //Recuperamos los valores de los campos de texto y combo
        val name = binding.etASName.text.toString()
        val quantity = binding.etASQuantity.text.toString()
        val quantityUnit = binding.sASQuantityUnit.selectedItem.toString()

        //Si el nombre no está vacio añadimos o actualizamos según el caso
        //Despues volvemos a la pantalla de Compra
        if (name.isNotEmpty()) {
            if (mode == MODE_ADD) {
                addShopPresenter.insertShop(name, quantity, quantityUnit)
            } else {
                addShopPresenter.updateShop(name, quantity, quantityUnit, idShop)
            }
            //En caso contrario indicamos al usuario que debe ponerlo
        } else {
            Popup.showInfo(
                requireContext(),
                resources,
                mutableTranslations[Constant.MSG_NAME_REQUIRED]!!
            )
        }
    }

    //Metodo que se ejecuta tras haber insertado o actualizado correctamente un producto
    //de compra en la base de datos
    override fun onInsertedOrUpdatedProduct(){
        loadFragment(ShopListFragment())
    }

    //Establecemos las traducciones
    override fun setTranslations() {
        binding.layoutAddShop.visibility = View.VISIBLE
        binding.lASName.text =
            mutableTranslations[Constant.LABEL_NAME]!!
        binding.lASQuantity.text =
            mutableTranslations[Constant.LABEL_QUANTITY]!!
        binding.lASQuantityUnit.text =
            mutableTranslations[Constant.LABEL_QUANTITY_UNIT]!!
        if (mode == MODE_ADD) {
            binding.header.titleHeader.text =
                mutableTranslations[Constant.TITLE_ADD_SHOPPING]!!
            binding.btnASProduct.text =
                mutableTranslations[Constant.BTN_ADD_SHOPPING]!!
        } else {
            binding.header.titleHeader.text =
                mutableTranslations[Constant.TITLE_UPDATE_SHOPPING]!!
            binding.btnASProduct.text =
                mutableTranslations[Constant.BTN_UPDATE_SHOPPING]!!
        }
    }

    //Metodo que nos permite navegar a otro Fragment o pantalla
    fun loadFragment(fragment: Fragment) {

        //Declaramos una transacción
        //Añadimos el fragment a la pila backStack (sirve para cuando
        //hacemos clic en el back button del movil)
        //Comiteamos
        val transaction = parentFragmentManager.beginTransaction()
        transaction.add(R.id.container, fragment)
        transaction.addToBackStack(null)
        transaction.commit()
    }
}